package Bundle::Locale::CLDR::Polynesia;

use version;

our $VERSION = version->declare('v0.34.4');

=head1 NAME

Bundle::Locale::CLDR::Polynesia

=head1 CONTENTS

Locale::CLDR::Locales::Fr 0.34.4
Locale::CLDR::Locales::To 0.34.4
Locale::CLDR::Locales::Fr::Any 0.34.4
Locale::CLDR::Locales::To::Any 0.34.4
Locale::CLDR::Locales::En::Any::As 0.34.4
Locale::CLDR::Locales::En::Any::Ck 0.34.4
Locale::CLDR::Locales::En::Any::Nu 0.34.4
Locale::CLDR::Locales::En::Any::Pn 0.34.4
Locale::CLDR::Locales::En::Any::Tk 0.34.4
Locale::CLDR::Locales::En::Any::To 0.34.4
Locale::CLDR::Locales::En::Any::Tv 0.34.4
Locale::CLDR::Locales::En::Any::Ws 0.34.4
Locale::CLDR::Locales::Fr::Any::Pf 0.34.4
Locale::CLDR::Locales::Fr::Any::Wf 0.34.4
Locale::CLDR::Locales::To::Any::To 0.34.4
Locale::CLDR::Locales::En::Any::001 0.34.4

=cut

1;

